@@ -6,7 +6,6 @@ import rich
 from typing import Literal, Tuple
 from pathlib import Path
 
-
 class Cli:
     def __init__(self):
         self._config = {
@@ -28,14 +27,18 @@ class Cli:
         self._db.write_immediately(block=True)
 
     def keys(self):
-        print(list(self._db.keys()))
+        from .string.color_string import rgb_string, color_const
+        print(rgb_string(str(list(self._db.keys())), color_const.GREEN))
 
 
     def get(self, key: str):
+        from .string.color_string import rgb_string
         data = self._db.pop(key, None)
         if data:
             with open(data["filename"], 'wb') as f:
                 f.write(data["content"])
+        else:
+            print(rgb_string(f"WARNING: {key} not found"))
 
     def clean(self):
         raise NotImplementedError
